@@ -105,18 +105,19 @@ class dModel(Model):
     ### 要不然以物质浓度的角度去设置方法来计算某一物质浓度的变化方程？
     ### 算了，时间导数不在model里面设置，毕竟会涉及多个菌群交换同一种物质
     def modify_reaction(
-        self,
-        reaction_id: str,  ## 需要修改的反应id
-        bound_direction: str,  ## 修改反应的上限还是下限？（输入应为: 'upper', 'lower', 'both'）
-        equation: str,  ## 修改后的反应方程
+            self,
+            reaction_id: str,  ## 需要修改的反应id
+            bound_direction: str,  ## 修改反应的上限还是下限？（输入应为: 'upper', 'lower', 'both'）
+            equation: str,  ## 修改后的反应方程
+            is_volume=True  ## 判断输入的酶动力学模型是以体积为单位还是以干重为单位
     ):
-        
+
         ## 要不要把反应上下限都设置成动力学速率，还是根据情况单独设置上限或下限？
         ## 我更偏向于单独设置下限或上限,因为留出的求解空间更大，但是应该怎么判断是设下限还是上限呢？
         ### 用什么形式储存该次修改方案？因为要到simulate里面才会代入数值
         ### 就用二维数组来储存吧（暂时的想法），到simulate里面再遍历取出来赋值
         ### 或者重写一个dReaction类，类里面新增reaction, bound_direction和equation三个属性（可行，效果和二维数组一样，只不过封装得好看点）
-        
+
         # 处理已经在dReaction列表中已有的反应，如果要修改只能删了重建
         for drxn in self.dReactions:
             if drxn.reaction.id == reaction_id:
@@ -124,12 +125,13 @@ class dModel(Model):
                 drxn.bound_direction = bound_direction
                 drxn.equation = equation
                 return
-        
+
         # 判断输入的bound_direction是否符合要求
         if (not bound_direction.startswith("upper")) and (not bound_direction.startswith("lower")) and (not bound_direction.startswith("both")):
             raise ValueError(f"'{bound_direction}'并非可设置的反应上下限, 请输入'upper', 'lower'或'both'.")
 
-        dreaction = dReaction(self.reactions.get_by_id(reaction_id), bound_direction, equation)
+        dreaction = dReaction(self.reactions.get_by_id(reaction_id), bound_direction, equation, is_volume)
+
         self.dReactions.append(dreaction)
 
 
