@@ -189,9 +189,10 @@ class solver():
                 model_mu = model_name + '_mu'  # 优化后的生长率flux值变量名
                 if model_mu in rxnsFluxValue_keys:  # 计算了这个菌的生长率, derivatives就不为0
                     dilution_rate = self.models_dict[model_name].dilrate
-                    derivative['d'] = self.states[state_name] * var[model_mu] - self.states_var[
-                        state_name] * dilution_rate
+                    derivative['d'] = self.states[state_name] * var[model_mu] - self.states_var[state_name] * dilution_rate
                     # print("导数: %f" % derivative['d'])
+            elif self.derivatives_description[state_name] == '0':
+                pass
             elif state_name in derivatives_keys:  # 要求计算这种物质时间导数
                 # derivative = 0
                 derivative_description = self.derivatives_description[state_name]  # 得到该物质的计算公式
@@ -202,7 +203,7 @@ class solver():
                     exec('var[item] =' + model_weight + '*' + item)
                     # print(item)
                     # print(var[item])
-                exec("derivative['d']=" + derivative_description)
+                exec("derivative['d']="+ derivative_description)
                 # print("导数: %f" % derivative['d'])
             derivatives.append(derivative['d'])
 
